@@ -25,12 +25,15 @@ class ExperimentalAssetsAPI(AssetsAPI):
         asset_subtree_ids: List[int] = None,
         asset_subtree_external_ids: List[str] = None,
         metadata: Dict[str, str] = None,
+        data_set_ids: List[int] = None,
+        data_set_external_ids: List[str] = None,
         source: str = None,
         created_time: Union[Dict[str, Any], TimestampRange] = None,
         last_updated_time: Union[Dict[str, Any], TimestampRange] = None,
         root: bool = None,
         external_id_prefix: str = None,
         types: List = None,
+        labels: List = None,
         aggregated_properties: List[str] = None,
         limit: int = None,
     ) -> Generator[Union[Asset, AssetList], None, None]:
@@ -47,12 +50,15 @@ class ExperimentalAssetsAPI(AssetsAPI):
             asset_subtree_ids (List[int]): List of asset subtrees ids to filter on.
             asset_subtree_external_ids (List[str]): List of asset subtrees external ids to filter on.
             metadata (Dict[str, str]): Custom, application specific metadata. String key -> String value
+            data_set_ids (List[int]): Return only assets in the specified data sets with these ids.
+            data_set_external_ids (List[str]): Return only assets in the specified data sets with these external ids.
             source (str): The source of this asset
             created_time (Union[Dict[str, int], TimestampRange]):  Range between two timestamps. Possible keys are `min` and `max`, with values given as time stamps in ms.
             last_updated_time (Union[Dict[str, int], TimestampRange]):  Range between two timestamps. Possible keys are `min` and `max`, with values given as time stamps in ms.
             root (bool): filtered assets are root assets or not
             external_id_prefix (str): Filter by this (case-sensitive) prefix for the external ID.
             types (List): List of type filters.
+            labels (List): List of label filters
             aggregated_properties (List[str]): Set of aggregated properties to include.
             limit (int, optional): Maximum number of assets to return. Defaults to return all items.
 
@@ -66,18 +72,23 @@ class ExperimentalAssetsAPI(AssetsAPI):
             root_ids = self._process_ids(root_ids, root_external_ids, wrap_ids=True)
         if asset_subtree_ids or asset_subtree_external_ids:
             asset_subtree_ids = self._process_ids(asset_subtree_ids, asset_subtree_external_ids, wrap_ids=True)
+        if data_set_ids or data_set_external_ids:
+            data_set_ids = self._process_ids(data_set_ids, data_set_external_ids, wrap_ids=True)
 
         filter = AssetFilter(
             name=name,
             parent_ids=parent_ids,
             root_ids=root_ids,
             asset_subtree_ids=asset_subtree_ids,
+            data_set_ids=data_set_ids,
             metadata=metadata,
             source=source,
             created_time=created_time,
             last_updated_time=last_updated_time,
             root=root,
             external_id_prefix=external_id_prefix,
+            types=types,
+            labels=labels,
         ).dump(camel_case=True)
         return self._list_generator(
             method="POST",
@@ -88,7 +99,7 @@ class ExperimentalAssetsAPI(AssetsAPI):
         )
 
     def create(self, asset: Union[Asset, List[Asset]]) -> Union[Asset, AssetList]:
-        """`Create one or more assets. <https://docs.cognite.com/api/v1/#operation/createAssets>`_
+        """`Create one or more assets. <https://docs.cognite.com/api/playground/#operation/createAssets>`_
 
         You can create an arbitrary number of assets, and the SDK will split the request into multiple requests.
 
@@ -111,9 +122,8 @@ class ExperimentalAssetsAPI(AssetsAPI):
         utils._auxiliary.assert_type(asset, "asset", [Asset, list])
         return self._create_multiple(asset)
 
-    @use_v1_instead_of_playground
     def retrieve(self, id: Optional[int] = None, external_id: Optional[str] = None) -> Optional[Asset]:
-        """`Retrieve a single asset by id. <https://docs.cognite.com/api/v1/#operation/getAsset>`_
+        """`Retrieve a single asset by id. <https://docs.cognite.com/api/playground/#operation/getAsset>`_
 
         Args:
             id (int, optional): ID
@@ -139,14 +149,13 @@ class ExperimentalAssetsAPI(AssetsAPI):
         utils._auxiliary.assert_exactly_one_of_id_or_external_id(id, external_id)
         return self._retrieve_multiple(ids=id, external_ids=external_id, wrap_ids=True)
 
-    @use_v1_instead_of_playground
     def retrieve_multiple(
         self,
         ids: Optional[List[int]] = None,
         external_ids: Optional[List[str]] = None,
         ignore_unknown_ids: bool = False,
     ) -> AssetList:
-        """`Retrieve multiple assets by id. <https://docs.cognite.com/api/v1/#operation/byIdsAssets>`_
+        """`Retrieve multiple assets by id. <https://docs.cognite.com/api/playground/#operation/byIdsAssets>`_
 
         Args:
             ids (List[int], optional): IDs
@@ -180,10 +189,13 @@ class ExperimentalAssetsAPI(AssetsAPI):
         self,
         name: str = None,
         parent_ids: List[int] = None,
+        parent_external_ids: List[str] = None,
         root_ids: List[int] = None,
         root_external_ids: List[str] = None,
         asset_subtree_ids: List[int] = None,
         asset_subtree_external_ids: List[str] = None,
+        data_set_ids: List[int] = None,
+        data_set_external_ids: List[str] = None,
         metadata: Dict[str, str] = None,
         source: str = None,
         created_time: Union[Dict[str, Any], TimestampRange] = None,
@@ -191,19 +203,23 @@ class ExperimentalAssetsAPI(AssetsAPI):
         root: bool = None,
         external_id_prefix: str = None,
         types: List = None,
+        labels: List = None,
         aggregated_properties: List[str] = None,
         partitions: int = None,
         limit: int = 25,
     ) -> AssetList:
-        """`List assets <https://docs.cognite.com/api/v1/#operation/listAssets>`_
+        """`List assets <https://docs.cognite.com/api/playground/#operation/listAssets>`_
 
         Args:
             name (str): Name of asset. Often referred to as tag.
             parent_ids (List[int]): Return only the direct descendants of the specified assets.
+            parent_external_ids (List[str]): Return only the direct descendants of the specified assets.
             root_ids (List[int], optional): List of root ids ids to filter on.
             root_external_ids (List[str], optional): List of root external ids to filter on.
             asset_subtree_ids (List[int]): List of asset subtrees ids to filter on.
             asset_subtree_external_ids (List[str]): List of asset subtrees external ids to filter on.
+            data_set_ids (List[int]): Return only assets in the specified data sets with these ids.
+            data_set_external_ids (List[str]): Return only assets in the specified data sets with these external ids.
             metadata (Dict[str, str]): Custom, application specific metadata. String key -> String value.
             source (str): The source of this asset.
             created_time (Union[Dict[str, int], TimestampRange]):  Range between two timestamps. Possible keys are `min` and `max`, with values given as time stamps in ms.
@@ -211,6 +227,7 @@ class ExperimentalAssetsAPI(AssetsAPI):
             root (bool): filtered assets are root assets or not.
             external_id_prefix (str): Filter by this (case-sensitive) prefix for the external ID.
             types (List): List of type filters.
+            labels (List): List of label filters.
             aggregated_properties (List[str]): Set of aggregated properties to include.
             partitions (int): Retrieve assets in parallel using this number of workers. Also requires `limit=None` to be passed.
             limit (int, optional): Maximum number of assets to return. Defaults to 25. Set to -1, float("inf") or None
@@ -249,12 +266,16 @@ class ExperimentalAssetsAPI(AssetsAPI):
             root_ids = self._process_ids(root_ids, root_external_ids, wrap_ids=True)
         if asset_subtree_ids or asset_subtree_external_ids:
             asset_subtree_ids = self._process_ids(asset_subtree_ids, asset_subtree_external_ids, wrap_ids=True)
+            asset_subtree_ids = self._process_ids(asset_subtree_ids, asset_subtree_external_ids, wrap_ids=True)
+        if data_set_ids or data_set_external_ids:
+            data_set_ids = self._process_ids(data_set_ids, data_set_external_ids, wrap_ids=True)
 
         filter = AssetFilter(
             name=name,
             parent_ids=parent_ids,
             root_ids=root_ids,
             asset_subtree_ids=asset_subtree_ids,
+            data_set_ids=data_set_ids,
             metadata=metadata,
             source=source,
             created_time=created_time,
@@ -262,6 +283,7 @@ class ExperimentalAssetsAPI(AssetsAPI):
             root=root,
             external_id_prefix=external_id_prefix,
             types=types,
+            labels=labels,
         ).dump(camel_case=True)
         return self._list(
             method="POST",
@@ -304,7 +326,7 @@ class ExperimentalAssetsAPI(AssetsAPI):
         recursive: bool = False,
         ignore_unknown_ids: bool = False,
     ) -> None:
-        """`Delete one or more assets <https://doc.cognitedata.com/api/v1/#operation/deleteAssets>`_
+        """`Delete one or more assets <https://doc.cognitedata.com/api/playground/#operation/deleteAssets>`_
 
         Args:
             id (Union[int, List[int]): Id or list of ids
@@ -331,7 +353,7 @@ class ExperimentalAssetsAPI(AssetsAPI):
         )
 
     def update(self, item: Union[Asset, AssetUpdate, List[Union[Asset, AssetUpdate]]]) -> Union[Asset, AssetList]:
-        """`Update one or more assets <https://docs.cognite.com/api/v1/#operation/updateAssets>`_
+        """`Update one or more assets <https://docs.cognite.com/api/playground/#operation/updateAssets>`_
 
         Args:
             item (Union[Asset, AssetUpdate, List[Union[Asset, AssetUpdate]]]): Asset(s) to update
@@ -367,7 +389,7 @@ class ExperimentalAssetsAPI(AssetsAPI):
         filter: Union[AssetFilter, Dict] = None,
         limit: int = 100,
     ) -> AssetList:
-        """`Search for assets <https://docs.cognite.com/api/v1/#operation/searchAssets>`_
+        """`Search for assets <https://docs.cognite.com/api/playground/#operation/searchAssets>`_
 
         Args:
             name (str): Fuzzy match on name.
